@@ -1,4 +1,5 @@
-from typing import Any, Dict
+""" Module to access the Imports endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
 
 from ..base import ApiBaseClass
 
@@ -17,21 +18,21 @@ class ImportsApi(ApiBaseClass):
             Must have `manage_system` permissions.
         Minimum Server Version:
             5.31
+
+        Api Reference:
+            `ListImports <https://api.mattermost.com/#operation/ListImports>`_
         """
 
-        url = "{}/imports".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/imports"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
