@@ -1,3 +1,6 @@
+""" Module to access the Posts endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
+
 from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
@@ -33,13 +36,14 @@ class PostsApi(ApiBaseClass):
         another post, provide `root_id`.
 
         Permissions:
-            Must have `create_post` permission for the channel the post is being
-        created in.
+            Must have `create_post` permission for the channel the post
+            is being created in.
+
+        Api Reference:
+            `CreatePost <https://api.mattermost.com/#operation/CreatePost>`_
         """
 
-        url = "{}/posts".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/posts"
         params: Dict[str, Any] = {
             "set_online": set_online,
         }
@@ -52,23 +56,22 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
             "params": params,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 201:
-            response_201 = Post.parse_obj(response.json())
+            response201 = Post.parse_obj(response.json())
 
-            return response_201
+            return response201
         return response
 
     async def create_post_ephemeral(
@@ -81,13 +84,14 @@ class PostsApi(ApiBaseClass):
         Create a new ephemeral post in a channel.
 
         Permissions:
-            Must have `create_post_ephemeral` permission (currently only given
-        to system admin)
+            Must have `create_post_ephemeral` permission (currently only
+            given to system admin)
+
+        Api Reference:
+            `CreatePostEphemeral <https://api.mattermost.com/#operation/CreatePostEphemeral>`_
         """
 
-        url = "{}/posts/ephemeral".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/posts/ephemeral"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -96,22 +100,21 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 201:
-            response_201 = Post.parse_obj(response.json())
+            response201 = Post.parse_obj(response.json())
 
-            return response_201
+            return response201
         return response
 
     async def get_post(
@@ -123,32 +126,32 @@ class PostsApi(ApiBaseClass):
         Get a single post.
 
         Permissions:
-            Must have `read_channel` permission for the channel the post is in
-        or if the channel is public, have the `read_public_channels` permission
-        for the team.
+            Must have `read_channel` permission for the channel the post
+            is in or if the channel is public, have the
+            `read_public_channels` permission for the team.
+
+        Api Reference:
+            `GetPost <https://api.mattermost.com/#operation/GetPost>`_
         """
 
-        url = "{}/posts/{post_id}".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = Post.parse_obj(response.json())
+            response200 = Post.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def update_post(
@@ -163,12 +166,14 @@ class PostsApi(ApiBaseClass):
         fields will be treated as blank.
 
         Permissions:
-            Must have `edit_post` permission for the channel the post is in.
+            Must have `edit_post` permission for the channel the post is
+            in.
+
+        Api Reference:
+            `UpdatePost <https://api.mattermost.com/#operation/UpdatePost>`_
         """
 
-        url = "{}/posts/{post_id}".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -177,22 +182,21 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = await self.client.put(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.put(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = Post.parse_obj(response.json())
+            response200 = Post.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def delete_post(
@@ -206,30 +210,30 @@ class PostsApi(ApiBaseClass):
 
         Permissions:
             Must be logged in as the user or have `delete_others_posts`
-        permission.
+            permission.
+
+        Api Reference:
+            `DeletePost <https://api.mattermost.com/#operation/DeletePost>`_
         """
 
-        url = "{}/posts/{post_id}".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.delete(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.delete(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def set_post_unread(
@@ -244,36 +248,34 @@ class PostsApi(ApiBaseClass):
         marking the post for himself.
 
         Permissions:
-            Must have `read_channel` permission for the channel the post is in
-        or if the channel is public, have the `read_public_channels` permission
-        for the team.
+            Must have `read_channel` permission for the channel the post
+            is in or if the channel is public, have the
+            `read_public_channels` permission for the team.
         Minimum Server Version:
             5.18
+
+        Api Reference:
+            `SetPostUnread <https://api.mattermost.com/#operation/SetPostUnread>`_
         """
 
-        url = "{}/users/{user_id}/posts/{post_id}/set_unread".format(
-            self.client.base_url, user_id=user_id, post_id=post_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/users/{user_id}/posts/{post_id}/set_unread"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = ChannelUnreadAt.parse_obj(response.json())
+            response200 = ChannelUnreadAt.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def patch_post(
@@ -290,11 +292,12 @@ class PostsApi(ApiBaseClass):
 
         Permissions:
             Must have the `edit_post` permission.
+
+        Api Reference:
+            `PatchPost <https://api.mattermost.com/#operation/PatchPost>`_
         """
 
-        url = "{}/posts/{post_id}/patch".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/patch"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -303,22 +306,21 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = await self.client.put(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.put(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = Post.parse_obj(response.json())
+            response200 = Post.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def get_post_thread(
@@ -330,32 +332,32 @@ class PostsApi(ApiBaseClass):
         Get a post and the rest of the posts in the same thread.
 
         Permissions:
-            Must have `read_channel` permission for the channel the post is in
-        or if the channel is public, have the `read_public_channels` permission
-        for the team.
+            Must have `read_channel` permission for the channel the post
+            is in or if the channel is public, have the
+            `read_public_channels` permission for the team.
+
+        Api Reference:
+            `GetPostThread <https://api.mattermost.com/#operation/GetPostThread>`_
         """
 
-        url = "{}/posts/{post_id}/thread".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/thread"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = PostList.parse_obj(response.json())
+            response200 = PostList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def get_flagged_posts_for_user(
@@ -375,13 +377,12 @@ class PostsApi(ApiBaseClass):
 
         Permissions:
             Must be user or have `manage_system` permission.
+
+        Api Reference:
+            `GetFlaggedPostsForUser <https://api.mattermost.com/#operation/GetFlaggedPostsForUser>`_
         """
 
-        url = "{}/users/{user_id}/posts/flagged".format(
-            self.client.base_url, user_id=user_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/users/{user_id}/posts/flagged"
         params: Dict[str, Any] = {
             "team_id": team_id,
             "channel_id": channel_id,
@@ -392,27 +393,26 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = PostList.parse_obj(response_200_item_data)
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = PostList.parse_obj(response200_item_data)
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
 
     async def get_file_infos_for_post(
@@ -425,37 +425,36 @@ class PostsApi(ApiBaseClass):
         post.
 
         Permissions:
-            Must have `read_channel` permission for the channel the post is in.
+            Must have `read_channel` permission for the channel the post
+            is in.
+
+        Api Reference:
+            `GetFileInfosForPost <https://api.mattermost.com/#operation/GetFileInfosForPost>`_
         """
 
-        url = "{}/posts/{post_id}/files/info".format(
-            self.client.base_url, post_id=post_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/files/info"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = FileInfo.parse_obj(response_200_item_data)
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = FileInfo.parse_obj(response200_item_data)
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
 
     async def get_posts_for_channel(
@@ -481,13 +480,12 @@ class PostsApi(ApiBaseClass):
 
         Permissions:
             Must have `read_channel` permission for the channel.
+
+        Api Reference:
+            `GetPostsForChannel <https://api.mattermost.com/#operation/GetPostsForChannel>`_
         """
 
-        url = "{}/channels/{channel_id}/posts".format(
-            self.client.base_url, channel_id=channel_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/channels/{channel_id}/posts"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -499,22 +497,21 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = PostList.parse_obj(response.json())
+            response200 = PostList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def get_posts_around_last_unread(
@@ -524,6 +521,9 @@ class PostsApi(ApiBaseClass):
         *,
         limit_before: Optional[int] = 60,
         limit_after: Optional[int] = 60,
+        skip_fetch_threads: Optional[bool] = False,
+        collapsed_threads: Optional[bool] = False,
+        collapsed_threads_extended: Optional[bool] = False,
     ) -> PostList:
         """Get posts around oldest unread
 
@@ -532,41 +532,43 @@ class PostsApi(ApiBaseClass):
         (most recent post first).
 
         Permissions:
-            Must be logged in as the user or have `edit_other_users` permission,
-        and must have `read_channel` permission for the channel.
+            Must be logged in as the user or have `edit_other_users`
+            permission, and must have `read_channel` permission for the
+            channel.
         Minimum Server Version:
             5.14
+
+        Api Reference:
+            `GetPostsAroundLastUnread <https://api.mattermost.com/#operation/GetPostsAroundLastUnread>`_
         """
 
-        url = "{}/users/{user_id}/channels/{channel_id}/posts/unread".format(
-            self.client.base_url, user_id=user_id, channel_id=channel_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/users/{user_id}/channels/{channel_id}/posts/unread"
         params: Dict[str, Any] = {
             "limit_before": limit_before,
             "limit_after": limit_after,
+            "skipFetchThreads": skip_fetch_threads,
+            "collapsedThreads": collapsed_threads,
+            "collapsedThreadsExtended": collapsed_threads_extended,
         }
         params = {k: v for k, v in params.items() if v is not None}
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = await self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = PostList.parse_obj(response.json())
+            response200 = PostList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def search_posts(
@@ -581,13 +583,12 @@ class PostsApi(ApiBaseClass):
 
         Permissions:
             Must be authenticated and have the `view_team` permission.
+
+        Api Reference:
+            `SearchPosts <https://api.mattermost.com/#operation/SearchPosts>`_
         """
 
-        url = "{}/teams/{team_id}/posts/search".format(
-            self.client.base_url, team_id=team_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/teams/{team_id}/posts/search"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -596,22 +597,21 @@ class PostsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = PostListWithSearchMatches.parse_obj(response.json())
+            response200 = PostListWithSearchMatches.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def pin_post(
@@ -623,31 +623,31 @@ class PostsApi(ApiBaseClass):
         Pin a post to a channel it is in based from the provided post id string.
 
         Permissions:
-            Must be authenticated and have the `read_channel` permission to the
-        channel the post is in.
+            Must be authenticated and have the `read_channel` permission
+            to the channel the post is in.
+
+        Api Reference:
+            `PinPost <https://api.mattermost.com/#operation/PinPost>`_
         """
 
-        url = "{}/posts/{post_id}/pin".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/pin"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def unpin_post(
@@ -660,31 +660,31 @@ class PostsApi(ApiBaseClass):
         string.
 
         Permissions:
-            Must be authenticated and have the `read_channel` permission to the
-        channel the post is in.
+            Must be authenticated and have the `read_channel` permission
+            to the channel the post is in.
+
+        Api Reference:
+            `UnpinPost <https://api.mattermost.com/#operation/UnpinPost>`_
         """
 
-        url = "{}/posts/{post_id}/unpin".format(self.client.base_url, post_id=post_id)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/unpin"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def do_post_action(
@@ -698,33 +698,31 @@ class PostsApi(ApiBaseClass):
         through posts.
 
         Permissions:
-            Must be authenticated and have the `read_channel` permission to the
-        channel the post is in.
+            Must be authenticated and have the `read_channel` permission
+            to the channel the post is in.
+
+        Api Reference:
+            `DoPostAction <https://api.mattermost.com/#operation/DoPostAction>`_
         """
 
-        url = "{}/posts/{post_id}/actions/{action_id}".format(
-            self.client.base_url, post_id=post_id, action_id=action_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/posts/{post_id}/actions/{action_id}"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     async def get_posts_by_ids(
@@ -737,37 +735,37 @@ class PostsApi(ApiBaseClass):
         Fetch a list of posts based on the provided postIDs
 
         Permissions:
-            Must have `read_channel` permission for the channel the post is in
-        or if the channel is public, have the `read_public_channels` permission
-        for the team.
+            Must have `read_channel` permission for the channel the post
+            is in or if the channel is public, have the
+            `read_public_channels` permission for the team.
+
+        Api Reference:
+            `GetPostsByIds <https://api.mattermost.com/#operation/GetPostsByIds>`_
         """
 
-        url = "{}/posts/ids".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/posts/ids"
         json_json_body = json_body
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = await self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        async with self.client._get_httpx_client() as httpx_client:
+            response = await httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = Post.parse_obj(response_200_item_data)
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = Post.parse_obj(response200_item_data)
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
