@@ -1,4 +1,5 @@
-from typing import Any, Dict
+""" Module to access the Bleve endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
 
 from ...models import StatusOK
 from ..base import ApiBaseClass
@@ -21,27 +22,27 @@ class BleveApi(ApiBaseClass):
             Must have `sysconsole_write_experimental` permission.
         Minimum Server Version:
             5.24
+
+        Api Reference:
+            `PurgeBleveIndexes <https://api.mattermost.com/#operation/PurgeBleveIndexes>`_
         """
 
-        url = "{}/bleve/purge_indexes".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/bleve/purge_indexes"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
