@@ -1,3 +1,6 @@
+""" Module to access the DataRetention endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
+
 from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
@@ -7,7 +10,7 @@ from ...models import (
     DataRetentionPolicyCreate,
     DataRetentionPolicyWithTeamAndChannelCounts,
     DataRetentionPolicyWithTeamAndChannelIds,
-    GetDataRetentionPoliciesCountResponse_200,
+    GetDataRetentionPoliciesCountResponse200,
     GlobalDataRetentionPolicy,
     RetentionPolicyForChannelList,
     RetentionPolicyForTeamList,
@@ -39,16 +42,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must be logged in as the user or have the `manage_system`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetTeamPoliciesForUser <https://api.mattermost.com/#operation/GetTeamPoliciesForUser>`_
         """
 
-        url = "{}/users/{user_id}/data_retention/team_policies".format(
-            self.client.base_url, user_id=user_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/users/{user_id}/data_retention/team_policies"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -57,22 +59,21 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = RetentionPolicyForTeamList.parse_obj(response.json())
+            response200 = RetentionPolicyForTeamList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def get_channel_policies_for_user(
@@ -92,16 +93,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must be logged in as the user or have the `manage_system`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetChannelPoliciesForUser <https://api.mattermost.com/#operation/GetChannelPoliciesForUser>`_
         """
 
-        url = "{}/users/{user_id}/data_retention/channel_policies".format(
-            self.client.base_url, user_id=user_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/users/{user_id}/data_retention/channel_policies"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -110,22 +110,21 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = RetentionPolicyForChannelList.parse_obj(response.json())
+            response200 = RetentionPolicyForChannelList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def get_data_retention_policy(
@@ -144,34 +143,34 @@ class DataRetentionApi(ApiBaseClass):
             Requires an active session but no other permissions.
         Minimum Server Version:
             4.3
+
+        Api Reference:
+            `GetDataRetentionPolicy <https://api.mattermost.com/#operation/GetDataRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policy".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/data_retention/policy"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = GlobalDataRetentionPolicy.parse_obj(response.json())
+            response200 = GlobalDataRetentionPolicy.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def get_data_retention_policies_count(
         self,
-    ) -> GetDataRetentionPoliciesCountResponse_200:
+    ) -> GetDataRetentionPoliciesCountResponse200:
         """Get the number of granular data retention policies
 
         Gets the number of granular (i.e. team or channel-specific) data
@@ -183,34 +182,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetDataRetentionPoliciesCount <https://api.mattermost.com/#operation/GetDataRetentionPoliciesCount>`_
         """
 
-        url = "{}/data_retention/policies_count".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/data_retention/policies_count"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = GetDataRetentionPoliciesCountResponse_200.parse_obj(
+            response200 = GetDataRetentionPoliciesCountResponse200.parse_obj(
                 response.json()
             )
 
-            return response_200
+            return response200
         return response
 
     def get_data_retention_policies(
@@ -230,14 +229,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetDataRetentionPolicies <https://api.mattermost.com/#operation/GetDataRetentionPolicies>`_
         """
 
-        url = "{}/data_retention/policies".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/data_retention/policies"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -246,31 +246,30 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = (
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = (
                     DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
-                        response_200_item_data
+                        response200_item_data
                     )
                 )
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
 
     def create_data_retention_policy(
@@ -288,14 +287,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `CreateDataRetentionPolicy <https://api.mattermost.com/#operation/CreateDataRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/data_retention/policies"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -304,24 +304,23 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 201:
-            response_201 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
+            response201 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
                 response.json()
             )
 
-            return response_201
+            return response201
         return response
 
     def get_data_retention_policy_by_id(
@@ -337,36 +336,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetDataRetentionPolicyByID <https://api.mattermost.com/#operation/GetDataRetentionPolicyByID>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
+            response200 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
                 response.json()
             )
 
-            return response_200
+            return response200
         return response
 
     def delete_data_retention_policy(
@@ -382,34 +379,32 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `DeleteDataRetentionPolicy <https://api.mattermost.com/#operation/DeleteDataRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}"
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
         }
-
-        response = self.client.delete(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.delete(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def patch_data_retention_policy(
@@ -428,16 +423,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `PatchDataRetentionPolicy <https://api.mattermost.com/#operation/PatchDataRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -446,24 +440,23 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.patch(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.patch(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
+            response200 = DataRetentionPolicyWithTeamAndChannelCounts.parse_obj(
                 response.json()
             )
 
-            return response_200
+            return response200
         return response
 
     def get_teams_for_retention_policy(
@@ -482,16 +475,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetTeamsForRetentionPolicy <https://api.mattermost.com/#operation/GetTeamsForRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/teams".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/teams"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -500,27 +492,26 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = Team.parse_obj(response_200_item_data)
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = Team.parse_obj(response200_item_data)
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
 
     def add_teams_to_retention_policy(
@@ -540,36 +531,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `AddTeamsToRetentionPolicy <https://api.mattermost.com/#operation/AddTeamsToRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/teams".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/teams"
         json_json_body = json_body
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def remove_teams_from_retention_policy(
@@ -589,36 +578,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `RemoveTeamsFromRetentionPolicy <https://api.mattermost.com/#operation/RemoveTeamsFromRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/teams".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/teams"
         json_json_body = json_body
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.delete(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.delete(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def search_teams_for_retention_policy(
@@ -637,16 +624,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `SearchTeamsForRetentionPolicy <https://api.mattermost.com/#operation/SearchTeamsForRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/teams/search".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/teams/search"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -655,27 +641,26 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = []
-            _response_200 = response.json()
-            for response_200_item_data in _response_200:
-                response_200_item = Team.parse_obj(response_200_item_data)
+            response200 = []
+            _response200 = response.json()
+            for response200_item_data in _response200:
+                response200_item = Team.parse_obj(response200_item_data)
 
-                response_200.append(response_200_item)
+                response200.append(response200_item)
 
-            return response_200
+            return response200
         return response
 
     def get_channels_for_retention_policy(
@@ -694,16 +679,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetChannelsForRetentionPolicy <https://api.mattermost.com/#operation/GetChannelsForRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/channels".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/channels"
         params: Dict[str, Any] = {
             "page": page,
             "per_page": per_page,
@@ -712,22 +696,21 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = ChannelListWithTeamData.parse_obj(response.json())
+            response200 = ChannelListWithTeamData.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def add_channels_to_retention_policy(
@@ -747,36 +730,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `AddChannelsToRetentionPolicy <https://api.mattermost.com/#operation/AddChannelsToRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/channels".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/channels"
         json_json_body = json_body
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def remove_channels_from_retention_policy(
@@ -796,36 +777,34 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_write_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `RemoveChannelsFromRetentionPolicy <https://api.mattermost.com/#operation/RemoveChannelsFromRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/channels".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/channels"
         json_json_body = json_body
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.delete(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.delete(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = StatusOK.parse_obj(response.json())
+            response200 = StatusOK.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
 
     def search_channels_for_retention_policy(
@@ -844,16 +823,15 @@ class DataRetentionApi(ApiBaseClass):
 
         Permissions:
             Must have the `sysconsole_read_compliance_data_retention`
-        permission.
+            permission.
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `SearchChannelsForRetentionPolicy <https://api.mattermost.com/#operation/SearchChannelsForRetentionPolicy>`_
         """
 
-        url = "{}/data_retention/policies/{policy_id}/channels/search".format(
-            self.client.base_url, policy_id=policy_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/data_retention/policies/{policy_id}/channels/search"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -862,20 +840,19 @@ class DataRetentionApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = ChannelListWithTeamData.parse_obj(response.json())
+            response200 = ChannelListWithTeamData.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
