@@ -1,4 +1,5 @@
-from typing import Any, Dict
+""" Module to access the OpenGraph endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
 
 from pydantic import BaseModel
 
@@ -23,11 +24,12 @@ class OpenGraphApi(ApiBaseClass):
             No permission required but must be logged in.
         Minimum Server Version:
             3.10
+
+        Api Reference:
+            `OpenGraph <https://api.mattermost.com/#operation/OpenGraph>`_
         """
 
-        url = "{}/opengraph".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/opengraph"
 
         if isinstance(json_body, BaseModel):
             json_json_body = json_body.dict(exclude_unset=True)
@@ -36,20 +38,19 @@ class OpenGraphApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "json": json_json_body,
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = OpenGraph.parse_obj(response.json())
+            response200 = OpenGraph.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
