@@ -1,3 +1,6 @@
+""" Module to access the Permissions endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
+
 from typing import Any, Dict, List, Optional, cast
 
 from ..base import ApiBaseClass
@@ -19,11 +22,12 @@ class PermissionsApi(ApiBaseClass):
 
         Minimum Server Version:
             5.35
+
+        Api Reference:
+            `GetAncillaryPermissions <https://api.mattermost.com/#operation/GetAncillaryPermissions>`_
         """
 
-        url = "{}/permissions/ancillary".format(self.client.base_url)
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = "/permissions/ancillary"
         params: Dict[str, Any] = {
             "subsection_permissions": subsection_permissions,
         }
@@ -31,20 +35,19 @@ class PermissionsApi(ApiBaseClass):
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "params": params,
         }
-
-        response = self.client.get(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.get(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = cast(List[str], response.json())
+            response200 = cast(List[str], response.json())
 
-            return response_200
+            return response200
         return response
