@@ -1,4 +1,5 @@
-from typing import Any, Dict
+""" Module to access the Search endpoints """
+# pylint: disable=too-many-lines,too-many-locals,too-many-public-methods
 
 from ...models import FileInfoList, SearchFilesMultipartData
 from ..base import ApiBaseClass
@@ -23,32 +24,30 @@ class SearchApi(ApiBaseClass):
             Must be authenticated and have the `view_team` permission.
         Minimum Server Version:
             5.34
+
+        Api Reference:
+            `SearchFiles <https://api.mattermost.com/#operation/SearchFiles>`_
         """
 
-        url = "{}/teams/{team_id}/files/search".format(
-            self.client.base_url, team_id=team_id
-        )
-        headers: Dict[str, Any] = self.client.get_headers()
-        cookies: Dict[str, Any] = self.client.get_cookies()
+        url = f"/teams/{team_id}/files/search"
 
         multipart_body_data = SearchFilesMultipartData.parse_obj(multipart_data)
 
         request_kwargs = {
             "url": url,
-            "headers": headers,
-            "cookies": cookies,
             "data": multipart_body_data.get_data(),
         }
-
-        response = self.client.post(
-            **request_kwargs,
-        )
+        # pylint: disable-next=protected-access
+        with self.client._get_httpx_client() as httpx_client:
+            response = httpx_client.post(
+                **request_kwargs,
+            )
 
         if self.skip_response_parsing:
             return response
 
         if response.status_code == 200:
-            response_200 = FileInfoList.parse_obj(response.json())
+            response200 = FileInfoList.parse_obj(response.json())
 
-            return response_200
+            return response200
         return response
